Transaction class

Constructors

Transaction({String? type, String? amount, String? currency, String? date, String? signedAmount, String? statusColor})
Transaction.fromJson(Map<String, dynamic> json)

Properties

amount ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
date ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signedAmount ↔ String?
getter/setter pair
status ↔ String?
getter/setter pair
statusColor ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
toUserJson() → Map<String, dynamic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited