AppContent class

Constructors

AppContent({String paymentSuccessful = '', String type = '', String id = '', String date = '', String method = '', String amount = '', String status = '', String total = '', String transactionIdCopied = '', String transactionDetailsCopied = '', String continueText = '', String createAccount = '', String or = '', String cardNumber = '', String otp = '', String error = '', String amountLabel = '', String currencySymbol = '', String continuePayment = '', String appName = '', String followSteps = '', String cardNumberHint = '', String enterOtp = '', String getOtpInstruction = '', String validate = '', String downloadApp = '', String cardIdError = '', String emptyOtpError = '', String otpLengthError = ''})
AppContent.fromMap(Map<String, dynamic> map)
Create object from Map
factory

Properties

amount → String
final
amountLabel → String
final
appName → String
final
cardIdError → String
final
cardNumber → String
final
cardNumberHint → String
final
continuePayment → String
final
continueText → String
final
createAccount → String
final
currencySymbol → String
final
date → String
final
downloadApp → String
final
emptyOtpError → String
final
enterOtp → String
final
error → String
final
followSteps → String
final
getOtpInstruction → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
method → String
final
or → String
final
otp → String
final
otpLengthError → String
final
paymentSuccessful → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
total → String
final
transactionDetailsCopied → String
final
transactionIdCopied → String
final
type → String
final
validate → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert object to Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited