PaymentWidgets class

Constructors

PaymentWidgets()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildCardNumberInput({required void onChanged(String), required TextEditingController cardIdController}) → Widget
buildContinueButton({required void onPressed(), required bool isLoading}) → Widget
buildCreateAccountButton() → Widget
buildOrDivider() → Widget
buildOtpSection({required TextEditingController otpController, void onChanged(String)?}) → Widget
buildPaymentInformation({required String amount}) → Widget
buildPaymentMethodSection() → Widget
initialize(AppContent translations) → void